@@ -16,9 +16,10 @@
 #pragma once
 #include <aws/apigatewayv2/ApiGatewayV2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/apigatewayv2/model/Cors.h>
 #include <aws/core/utils/DateTime.h>
-#include <aws/apigatewayv2/model/ProtocolType.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
+#include <aws/apigatewayv2/model/ProtocolType.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
 
@@ -53,73 +54,57 @@ namespace Model
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline const Aws::String& GetApiEndpoint() const{ return m_apiEndpoint; }
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline bool ApiEndpointHasBeenSet() const { return m_apiEndpointHasBeenSet; }
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline void SetApiEndpoint(const Aws::String& value) { m_apiEndpointHasBeenSet = true; m_apiEndpoint = value; }
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline void SetApiEndpoint(Aws::String&& value) { m_apiEndpointHasBeenSet = true; m_apiEndpoint = std::move(value); }
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline void SetApiEndpoint(const char* value) { m_apiEndpointHasBeenSet = true; m_apiEndpoint.assign(value); }
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline Api& WithApiEndpoint(const Aws::String& value) { SetApiEndpoint(value); return *this;}
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline Api& WithApiEndpoint(Aws::String&& value) { SetApiEndpoint(std::move(value)); return *this;}
 
     /**
      * <p>The URI of the API, of the form {api-id}.execute-api.{region}.amazonaws.com.
-     * The
- stage name is typically appended to this URI to form a complete path to a
-     * deployed
- API stage.</p>
+     * The stage name is typically appended to this URI to form a complete path to a
+     * deployed API stage.</p>
      */
     inline Api& WithApiEndpoint(const char* value) { SetApiEndpoint(value); return *this;}
 
@@ -166,62 +151,93 @@ namespace Model
 
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline const Aws::String& GetApiKeySelectionExpression() const{ return m_apiKeySelectionExpression; }
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline bool ApiKeySelectionExpressionHasBeenSet() const { return m_apiKeySelectionExpressionHasBeenSet; }
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline void SetApiKeySelectionExpression(const Aws::String& value) { m_apiKeySelectionExpressionHasBeenSet = true; m_apiKeySelectionExpression = value; }
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline void SetApiKeySelectionExpression(Aws::String&& value) { m_apiKeySelectionExpressionHasBeenSet = true; m_apiKeySelectionExpression = std::move(value); }
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline void SetApiKeySelectionExpression(const char* value) { m_apiKeySelectionExpressionHasBeenSet = true; m_apiKeySelectionExpression.assign(value); }
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline Api& WithApiKeySelectionExpression(const Aws::String& value) { SetApiKeySelectionExpression(value); return *this;}
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline Api& WithApiKeySelectionExpression(Aws::String&& value) { SetApiKeySelectionExpression(std::move(value)); return *this;}
 
     /**
-     * <p>An API key selection expression. See <a
+     * <p>An API key selection expression. Supported only for WebSocket APIs. See <a
      * href="https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-apikey-selection-expressions">API
      * Key Selection Expressions</a>.</p>
      */
     inline Api& WithApiKeySelectionExpression(const char* value) { SetApiKeySelectionExpression(value); return *this;}
 
 
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline const Cors& GetCorsConfiguration() const{ return m_corsConfiguration; }
+
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline bool CorsConfigurationHasBeenSet() const { return m_corsConfigurationHasBeenSet; }
+
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline void SetCorsConfiguration(const Cors& value) { m_corsConfigurationHasBeenSet = true; m_corsConfiguration = value; }
+
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline void SetCorsConfiguration(Cors&& value) { m_corsConfigurationHasBeenSet = true; m_corsConfiguration = std::move(value); }
+
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline Api& WithCorsConfiguration(const Cors& value) { SetCorsConfiguration(value); return *this;}
+
+    /**
+     * <p>A CORS configuration. Supported only for HTTP APIs.</p>
+     */
+    inline Api& WithCorsConfiguration(Cors&& value) { SetCorsConfiguration(std::move(value)); return *this;}
+
+
     /**
      * <p>The timestamp when the API was created.</p>
      */
@@ -295,26 +311,94 @@ namespace Model
 
 
     /**
-     * <p>Avoid validating models when creating a deployment.</p>
+     * <p>Avoid validating models when creating a deployment. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool GetDisableSchemaValidation() const{ return m_disableSchemaValidation; }
 
     /**
-     * <p>Avoid validating models when creating a deployment.</p>
+     * <p>Avoid validating models when creating a deployment. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool DisableSchemaValidationHasBeenSet() const { return m_disableSchemaValidationHasBeenSet; }
 
     /**
-     * <p>Avoid validating models when creating a deployment.</p>
+     * <p>Avoid validating models when creating a deployment. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetDisableSchemaValidation(bool value) { m_disableSchemaValidationHasBeenSet = true; m_disableSchemaValidation = value; }
 
     /**
-     * <p>Avoid validating models when creating a deployment.</p>
+     * <p>Avoid validating models when creating a deployment. Supported only for
+     * WebSocket APIs.</p>
      */
     inline Api& WithDisableSchemaValidation(bool value) { SetDisableSchemaValidation(value); return *this;}
 
 
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetImportInfo() const{ return m_importInfo; }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline bool ImportInfoHasBeenSet() const { return m_importInfoHasBeenSet; }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline void SetImportInfo(const Aws::Vector<Aws::String>& value) { m_importInfoHasBeenSet = true; m_importInfo = value; }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline void SetImportInfo(Aws::Vector<Aws::String>&& value) { m_importInfoHasBeenSet = true; m_importInfo = std::move(value); }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline Api& WithImportInfo(const Aws::Vector<Aws::String>& value) { SetImportInfo(value); return *this;}
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline Api& WithImportInfo(Aws::Vector<Aws::String>&& value) { SetImportInfo(std::move(value)); return *this;}
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline Api& AddImportInfo(const Aws::String& value) { m_importInfoHasBeenSet = true; m_importInfo.push_back(value); return *this; }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline Api& AddImportInfo(Aws::String&& value) { m_importInfoHasBeenSet = true; m_importInfo.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The validation information during API import. This may include particular
+     * properties of your OpenAPI definition which are ignored during import. Supported
+     * only for HTTP APIs.</p>
+     */
+    inline Api& AddImportInfo(const char* value) { m_importInfoHasBeenSet = true; m_importInfo.push_back(value); return *this; }
+
+
     /**
      * <p>The name of the API.</p>
      */
@@ -357,77 +441,167 @@ namespace Model
 
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline const ProtocolType& GetProtocolType() const{ return m_protocolType; }
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline bool ProtocolTypeHasBeenSet() const { return m_protocolTypeHasBeenSet; }
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline void SetProtocolType(const ProtocolType& value) { m_protocolTypeHasBeenSet = true; m_protocolType = value; }
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline void SetProtocolType(ProtocolType&& value) { m_protocolTypeHasBeenSet = true; m_protocolType = std::move(value); }
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline Api& WithProtocolType(const ProtocolType& value) { SetProtocolType(value); return *this;}
 
     /**
-     * <p>The API protocol: Currently only WEBSOCKET is supported.</p>
+     * <p>The API protocol.</p>
      */
     inline Api& WithProtocolType(ProtocolType&& value) { SetProtocolType(std::move(value)); return *this;}
 
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline const Aws::String& GetRouteSelectionExpression() const{ return m_routeSelectionExpression; }
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline bool RouteSelectionExpressionHasBeenSet() const { return m_routeSelectionExpressionHasBeenSet; }
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteSelectionExpression(const Aws::String& value) { m_routeSelectionExpressionHasBeenSet = true; m_routeSelectionExpression = value; }
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteSelectionExpression(Aws::String&& value) { m_routeSelectionExpressionHasBeenSet = true; m_routeSelectionExpression = std::move(value); }
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteSelectionExpression(const char* value) { m_routeSelectionExpressionHasBeenSet = true; m_routeSelectionExpression.assign(value); }
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline Api& WithRouteSelectionExpression(const Aws::String& value) { SetRouteSelectionExpression(value); return *this;}
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline Api& WithRouteSelectionExpression(Aws::String&& value) { SetRouteSelectionExpression(std::move(value)); return *this;}
 
     /**
-     * <p>The route selection expression for the API.</p>
+     * <p>The route selection expression for the API. For HTTP APIs, the
+     * routeSelectionExpression must be ${request.method} ${request.path}. If not
+     * provided, this will be the default for HTTP APIs. This property is required for
+     * WebSocket APIs.</p>
      */
     inline Api& WithRouteSelectionExpression(const char* value) { SetRouteSelectionExpression(value); return *this;}
 
 
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
+
+    /**
+     * <p>A collection of tags associated with the API.</p>
+     */
+    inline Api& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
+
+
     /**
      * <p>A version identifier for the API.</p>
      */
@@ -470,160 +644,59 @@ namespace Model
 
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline const Aws::Vector<Aws::String>& GetWarnings() const{ return m_warnings; }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline bool WarningsHasBeenSet() const { return m_warningsHasBeenSet; }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline void SetWarnings(const Aws::Vector<Aws::String>& value) { m_warningsHasBeenSet = true; m_warnings = value; }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline void SetWarnings(Aws::Vector<Aws::String>&& value) { m_warningsHasBeenSet = true; m_warnings = std::move(value); }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline Api& WithWarnings(const Aws::Vector<Aws::String>& value) { SetWarnings(value); return *this;}
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline Api& WithWarnings(Aws::Vector<Aws::String>&& value) { SetWarnings(std::move(value)); return *this;}
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline Api& AddWarnings(const Aws::String& value) { m_warningsHasBeenSet = true; m_warnings.push_back(value); return *this; }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline Api& AddWarnings(Aws::String&& value) { m_warningsHasBeenSet = true; m_warnings.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The warning messages reported when failonwarnings is turned on during
- API
+     * <p>The warning messages reported when failonwarnings is turned on during API
      * import.</p>
      */
     inline Api& AddWarnings(const char* value) { m_warningsHasBeenSet = true; m_warnings.push_back(value); return *this; }
 
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
-
-    /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
-     */
-    inline Api& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
-
   private:
 
     Aws::String m_apiEndpoint;
@@ -635,6 +708,9 @@ namespace Model
     Aws::String m_apiKeySelectionExpression;
     bool m_apiKeySelectionExpressionHasBeenSet;
 
+    Cors m_corsConfiguration;
+    bool m_corsConfigurationHasBeenSet;
+
     Aws::Utils::DateTime m_createdDate;
     bool m_createdDateHasBeenSet;
 
@@ -644,6 +720,9 @@ namespace Model
     bool m_disableSchemaValidation;
     bool m_disableSchemaValidationHasBeenSet;
 
+    Aws::Vector<Aws::String> m_importInfo;
+    bool m_importInfoHasBeenSet;
+
     Aws::String m_name;
     bool m_nameHasBeenSet;
 
@@ -653,14 +732,14 @@ namespace Model
     Aws::String m_routeSelectionExpression;
     bool m_routeSelectionExpressionHasBeenSet;
 
+    Aws::Map<Aws::String, Aws::String> m_tags;
+    bool m_tagsHasBeenSet;
+
     Aws::String m_version;
     bool m_versionHasBeenSet;
 
     Aws::Vector<Aws::String> m_warnings;
     bool m_warningsHasBeenSet;
-
-    Aws::Map<Aws::String, Aws::String> m_tags;
-    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
