@@ -31,6 +31,10 @@ namespace Model
 {
 
   /**
+   * <p>Creates a new Route resource to represent a route.</p><p><h3>See Also:</h3>  
+   * <a
+   * href="http://docs.aws.amazon.com/goto/WebAPI/apigatewayv2-2018-11-29/CreateRouteRequest">AWS
+   * API Reference</a></p>
    */
   class AWS_APIGATEWAYV2_API CreateRouteRequest : public ApiGatewayV2Request
   {
@@ -88,260 +92,227 @@ namespace Model
 
 
     /**
-     * <p>Specifies whether an API key is required for the route.</p>
+     * <p>Specifies whether an API key is required for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool GetApiKeyRequired() const{ return m_apiKeyRequired; }
 
     /**
-     * <p>Specifies whether an API key is required for the route.</p>
+     * <p>Specifies whether an API key is required for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool ApiKeyRequiredHasBeenSet() const { return m_apiKeyRequiredHasBeenSet; }
 
     /**
-     * <p>Specifies whether an API key is required for the route.</p>
+     * <p>Specifies whether an API key is required for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetApiKeyRequired(bool value) { m_apiKeyRequiredHasBeenSet = true; m_apiKeyRequired = value; }
 
     /**
-     * <p>Specifies whether an API key is required for the route.</p>
+     * <p>Specifies whether an API key is required for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithApiKeyRequired(bool value) { SetApiKeyRequired(value); return *this;}
 
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline const Aws::Vector<Aws::String>& GetAuthorizationScopes() const{ return m_authorizationScopes; }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline bool AuthorizationScopesHasBeenSet() const { return m_authorizationScopesHasBeenSet; }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline void SetAuthorizationScopes(const Aws::Vector<Aws::String>& value) { m_authorizationScopesHasBeenSet = true; m_authorizationScopes = value; }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline void SetAuthorizationScopes(Aws::Vector<Aws::String>&& value) { m_authorizationScopesHasBeenSet = true; m_authorizationScopes = std::move(value); }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline CreateRouteRequest& WithAuthorizationScopes(const Aws::Vector<Aws::String>& value) { SetAuthorizationScopes(value); return *this;}
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline CreateRouteRequest& WithAuthorizationScopes(Aws::Vector<Aws::String>&& value) { SetAuthorizationScopes(std::move(value)); return *this;}
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline CreateRouteRequest& AddAuthorizationScopes(const Aws::String& value) { m_authorizationScopesHasBeenSet = true; m_authorizationScopes.push_back(value); return *this; }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline CreateRouteRequest& AddAuthorizationScopes(Aws::String&& value) { m_authorizationScopesHasBeenSet = true; m_authorizationScopes.push_back(std::move(value)); return *this; }
 
     /**
-     * <p>The authorization scopes supported by this
- route.</p>
+     * <p>The authorization scopes supported by this route.</p>
      */
     inline CreateRouteRequest& AddAuthorizationScopes(const char* value) { m_authorizationScopesHasBeenSet = true; m_authorizationScopes.push_back(value); return *this; }
 
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline const AuthorizationType& GetAuthorizationType() const{ return m_authorizationType; }
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline bool AuthorizationTypeHasBeenSet() const { return m_authorizationTypeHasBeenSet; }
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline void SetAuthorizationType(const AuthorizationType& value) { m_authorizationTypeHasBeenSet = true; m_authorizationType = value; }
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline void SetAuthorizationType(AuthorizationType&& value) { m_authorizationTypeHasBeenSet = true; m_authorizationType = std::move(value); }
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline CreateRouteRequest& WithAuthorizationType(const AuthorizationType& value) { SetAuthorizationType(value); return *this;}
 
     /**
-     * <p>The authorization type for the route. Valid values are NONE for open
- access,
-     * AWS_IAM for using AWS IAM permissions, and CUSTOM
- for using a Lambda
-
-     * authorizer.</p>
+     * <p>The authorization type for the route. For WebSocket APIs, valid values are
+     * NONE for open access, AWS_IAM for using AWS IAM permissions, and CUSTOM for
+     * using a Lambda authorizer For HTTP APIs, valid values are NONE for open access,
+     * or JWT for using JSON Web Tokens.</p>
      */
     inline CreateRouteRequest& WithAuthorizationType(AuthorizationType&& value) { SetAuthorizationType(std::move(value)); return *this;}
 
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline const Aws::String& GetAuthorizerId() const{ return m_authorizerId; }
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline bool AuthorizerIdHasBeenSet() const { return m_authorizerIdHasBeenSet; }
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline void SetAuthorizerId(const Aws::String& value) { m_authorizerIdHasBeenSet = true; m_authorizerId = value; }
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline void SetAuthorizerId(Aws::String&& value) { m_authorizerIdHasBeenSet = true; m_authorizerId = std::move(value); }
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline void SetAuthorizerId(const char* value) { m_authorizerIdHasBeenSet = true; m_authorizerId.assign(value); }
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline CreateRouteRequest& WithAuthorizerId(const Aws::String& value) { SetAuthorizerId(value); return *this;}
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline CreateRouteRequest& WithAuthorizerId(Aws::String&& value) { SetAuthorizerId(std::move(value)); return *this;}
 
     /**
-     * <p>The identifier of the Authorizer resource to be associated with this
- route,
-     * if the authorizationType is CUSTOM
- . The authorizer identifier is generated by
-     * API Gateway
- when you created the authorizer.</p>
+     * <p>The identifier of the Authorizer resource to be associated with this route.
+     * The authorizer identifier is generated by API Gateway when you created the
+     * authorizer.</p>
      */
     inline CreateRouteRequest& WithAuthorizerId(const char* value) { SetAuthorizerId(value); return *this;}
 
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline const Aws::String& GetModelSelectionExpression() const{ return m_modelSelectionExpression; }
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline bool ModelSelectionExpressionHasBeenSet() const { return m_modelSelectionExpressionHasBeenSet; }
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline void SetModelSelectionExpression(const Aws::String& value) { m_modelSelectionExpressionHasBeenSet = true; m_modelSelectionExpression = value; }
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline void SetModelSelectionExpression(Aws::String&& value) { m_modelSelectionExpressionHasBeenSet = true; m_modelSelectionExpression = std::move(value); }
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline void SetModelSelectionExpression(const char* value) { m_modelSelectionExpressionHasBeenSet = true; m_modelSelectionExpression.assign(value); }
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline CreateRouteRequest& WithModelSelectionExpression(const Aws::String& value) { SetModelSelectionExpression(value); return *this;}
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline CreateRouteRequest& WithModelSelectionExpression(Aws::String&& value) { SetModelSelectionExpression(std::move(value)); return *this;}
 
     /**
-     * <p>The model selection expression for the route.</p>
+     * <p>The model selection expression for the route. Supported only for WebSocket
+     * APIs.</p>
      */
     inline CreateRouteRequest& WithModelSelectionExpression(const char* value) { SetModelSelectionExpression(value); return *this;}
 
@@ -388,128 +359,128 @@ namespace Model
 
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetRequestModels() const{ return m_requestModels; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline bool RequestModelsHasBeenSet() const { return m_requestModelsHasBeenSet; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline void SetRequestModels(const Aws::Map<Aws::String, Aws::String>& value) { m_requestModelsHasBeenSet = true; m_requestModels = value; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline void SetRequestModels(Aws::Map<Aws::String, Aws::String>&& value) { m_requestModelsHasBeenSet = true; m_requestModels = std::move(value); }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRequestModels(const Aws::Map<Aws::String, Aws::String>& value) { SetRequestModels(value); return *this;}
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRequestModels(Aws::Map<Aws::String, Aws::String>&& value) { SetRequestModels(std::move(value)); return *this;}
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(const Aws::String& key, const Aws::String& value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(key, value); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(Aws::String&& key, const Aws::String& value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(const Aws::String& key, Aws::String&& value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(Aws::String&& key, Aws::String&& value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(const char* key, Aws::String&& value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(Aws::String&& key, const char* value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The request models for the route.</p>
+     * <p>The request models for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestModels(const char* key, const char* value) { m_requestModelsHasBeenSet = true; m_requestModels.emplace(key, value); return *this; }
 
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline const Aws::Map<Aws::String, ParameterConstraints>& GetRequestParameters() const{ return m_requestParameters; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline bool RequestParametersHasBeenSet() const { return m_requestParametersHasBeenSet; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline void SetRequestParameters(const Aws::Map<Aws::String, ParameterConstraints>& value) { m_requestParametersHasBeenSet = true; m_requestParameters = value; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline void SetRequestParameters(Aws::Map<Aws::String, ParameterConstraints>&& value) { m_requestParametersHasBeenSet = true; m_requestParameters = std::move(value); }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRequestParameters(const Aws::Map<Aws::String, ParameterConstraints>& value) { SetRequestParameters(value); return *this;}
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRequestParameters(Aws::Map<Aws::String, ParameterConstraints>&& value) { SetRequestParameters(std::move(value)); return *this;}
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(const Aws::String& key, const ParameterConstraints& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(key, value); return *this; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(Aws::String&& key, const ParameterConstraints& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(const Aws::String& key, ParameterConstraints&& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(Aws::String&& key, ParameterConstraints&& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(const char* key, ParameterConstraints&& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The request parameters for the route.</p>
+     * <p>The request parameters for the route. Supported only for WebSocket APIs.</p>
      */
     inline CreateRouteRequest& AddRequestParameters(const char* key, const ParameterConstraints& value) { m_requestParametersHasBeenSet = true; m_requestParameters.emplace(key, value); return *this; }
 
@@ -556,42 +527,50 @@ namespace Model
 
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline const Aws::String& GetRouteResponseSelectionExpression() const{ return m_routeResponseSelectionExpression; }
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool RouteResponseSelectionExpressionHasBeenSet() const { return m_routeResponseSelectionExpressionHasBeenSet; }
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteResponseSelectionExpression(const Aws::String& value) { m_routeResponseSelectionExpressionHasBeenSet = true; m_routeResponseSelectionExpression = value; }
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteResponseSelectionExpression(Aws::String&& value) { m_routeResponseSelectionExpressionHasBeenSet = true; m_routeResponseSelectionExpression = std::move(value); }
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetRouteResponseSelectionExpression(const char* value) { m_routeResponseSelectionExpressionHasBeenSet = true; m_routeResponseSelectionExpression.assign(value); }
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRouteResponseSelectionExpression(const Aws::String& value) { SetRouteResponseSelectionExpression(value); return *this;}
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRouteResponseSelectionExpression(Aws::String&& value) { SetRouteResponseSelectionExpression(std::move(value)); return *this;}
 
     /**
-     * <p>The route response selection expression for the route.</p>
+     * <p>The route response selection expression for the route. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateRouteRequest& WithRouteResponseSelectionExpression(const char* value) { SetRouteResponseSelectionExpression(value); return *this;}
 
