@@ -30,6 +30,10 @@ namespace Model
 {
 
   /**
+   * <p>Creates a new Stage resource to represent a stage.</p><p><h3>See Also:</h3>  
+   * <a
+   * href="http://docs.aws.amazon.com/goto/WebAPI/apigatewayv2-2018-11-29/CreateStageRequest">AWS
+   * API Reference</a></p>
    */
   class AWS_APIGATEWAYV2_API CreateStageRequest : public ApiGatewayV2Request
   {
@@ -118,42 +122,75 @@ namespace Model
 
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline bool GetAutoDeploy() const{ return m_autoDeploy; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline bool AutoDeployHasBeenSet() const { return m_autoDeployHasBeenSet; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline void SetAutoDeploy(bool value) { m_autoDeployHasBeenSet = true; m_autoDeploy = value; }
+
+    /**
+     * <p>Specifies whether updates to an API automatically trigger a new deployment.
+     * The default value is false.</p>
+     */
+    inline CreateStageRequest& WithAutoDeploy(bool value) { SetAutoDeploy(value); return *this;}
+
+
+    /**
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline const Aws::String& GetClientCertificateId() const{ return m_clientCertificateId; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline bool ClientCertificateIdHasBeenSet() const { return m_clientCertificateIdHasBeenSet; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(const Aws::String& value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId = value; }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(Aws::String&& value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId = std::move(value); }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline void SetClientCertificateId(const char* value) { m_clientCertificateIdHasBeenSet = true; m_clientCertificateId.assign(value); }
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateStageRequest& WithClientCertificateId(const Aws::String& value) { SetClientCertificateId(value); return *this;}
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateStageRequest& WithClientCertificateId(Aws::String&& value) { SetClientCertificateId(std::move(value)); return *this;}
 
     /**
-     * <p>The identifier of a client certificate for a Stage.</p>
+     * <p>The identifier of a client certificate for a Stage. Supported only for
+     * WebSocket APIs.</p>
      */
     inline CreateStageRequest& WithClientCertificateId(const char* value) { SetClientCertificateId(value); return *this;}
 
@@ -272,62 +309,62 @@ namespace Model
 
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline const Aws::Map<Aws::String, RouteSettings>& GetRouteSettings() const{ return m_routeSettings; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline bool RouteSettingsHasBeenSet() const { return m_routeSettingsHasBeenSet; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline void SetRouteSettings(const Aws::Map<Aws::String, RouteSettings>& value) { m_routeSettingsHasBeenSet = true; m_routeSettings = value; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline void SetRouteSettings(Aws::Map<Aws::String, RouteSettings>&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings = std::move(value); }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& WithRouteSettings(const Aws::Map<Aws::String, RouteSettings>& value) { SetRouteSettings(value); return *this;}
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& WithRouteSettings(Aws::Map<Aws::String, RouteSettings>&& value) { SetRouteSettings(std::move(value)); return *this;}
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(const Aws::String& key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, value); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(Aws::String&& key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(const Aws::String& key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(Aws::String&& key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(const char* key, RouteSettings&& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>Route settings for the stage.</p>
+     * <p>Route settings for the stage, by routeKey.</p>
      */
     inline CreateStageRequest& AddRouteSettings(const char* key, const RouteSettings& value) { m_routeSettingsHasBeenSet = true; m_routeSettings.emplace(key, value); return *this; }
 
@@ -374,211 +411,172 @@ namespace Model
 
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetStageVariables() const{ return m_stageVariables; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline bool StageVariablesHasBeenSet() const { return m_stageVariablesHasBeenSet; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline void SetStageVariables(const Aws::Map<Aws::String, Aws::String>& value) { m_stageVariablesHasBeenSet = true; m_stageVariables = value; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline void SetStageVariables(Aws::Map<Aws::String, Aws::String>&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables = std::move(value); }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& WithStageVariables(const Aws::Map<Aws::String, Aws::String>& value) { SetStageVariables(value); return *this;}
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& WithStageVariables(Aws::Map<Aws::String, Aws::String>&& value) { SetStageVariables(std::move(value)); return *this;}
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(const Aws::String& key, const Aws::String& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, value); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(Aws::String&& key, const Aws::String& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(const Aws::String& key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(Aws::String&& key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(const char* key, Aws::String&& value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(Aws::String&& key, const char* value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>A map that defines the stage variables for a Stage. Variable names
- can have
+     * <p>A map that defines the stage variables for a Stage. Variable names can have
      * alphanumeric and underscore characters, and the values must match
-
-     * [A-Za-z0-9-._~:/?#&=,]+.</p>
+     * [A-Za-z0-9-._~:/?#&amp;=,]+. Supported only for WebSocket APIs.</p>
      */
     inline CreateStageRequest& AddStageVariables(const char* key, const char* value) { m_stageVariablesHasBeenSet = true; m_stageVariables.emplace(key, value); return *this; }
 
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline const Aws::Map<Aws::String, Aws::String>& GetTags() const{ return m_tags; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline void SetTags(const Aws::Map<Aws::String, Aws::String>& value) { m_tagsHasBeenSet = true; m_tags = value; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline void SetTags(Aws::Map<Aws::String, Aws::String>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& WithTags(const Aws::Map<Aws::String, Aws::String>& value) { SetTags(value); return *this;}
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& WithTags(Aws::Map<Aws::String, Aws::String>&& value) { SetTags(std::move(value)); return *this;}
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(const Aws::String& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(Aws::String&& key, const Aws::String& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(const Aws::String& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(Aws::String&& key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(const char* key, Aws::String&& value) { m_tagsHasBeenSet = true; m_tags.emplace(key, std::move(value)); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(Aws::String&& key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(std::move(key), value); return *this; }
 
     /**
-     * <p>The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The
-     * tag key can be up to 128 characters and must not start with aws:. The tag value
-     * can be up to 256 characters..</p>
+     * <p>The collection of tags. Each tag element is associated with a given
+     * resource.</p>
      */
     inline CreateStageRequest& AddTags(const char* key, const char* value) { m_tagsHasBeenSet = true; m_tags.emplace(key, value); return *this; }
 
@@ -590,6 +588,9 @@ namespace Model
     Aws::String m_apiId;
     bool m_apiIdHasBeenSet;
 
+    bool m_autoDeploy;
+    bool m_autoDeployHasBeenSet;
+
     Aws::String m_clientCertificateId;
     bool m_clientCertificateIdHasBeenSet;
 
