@@ -484,14 +484,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline const Aws::String& GetLogDestination() const{ return m_logDestination; }
@@ -500,14 +504,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline bool LogDestinationHasBeenSet() const { return m_logDestinationHasBeenSet; }
@@ -516,14 +524,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline void SetLogDestination(const Aws::String& value) { m_logDestinationHasBeenSet = true; m_logDestination = value; }
@@ -532,14 +544,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline void SetLogDestination(Aws::String&& value) { m_logDestinationHasBeenSet = true; m_logDestination = std::move(value); }
@@ -548,14 +564,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline void SetLogDestination(const char* value) { m_logDestinationHasBeenSet = true; m_logDestination.assign(value); }
@@ -564,14 +584,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline CreateFlowLogsRequest& WithLogDestination(const Aws::String& value) { SetLogDestination(value); return *this;}
@@ -580,14 +604,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline CreateFlowLogsRequest& WithLogDestination(Aws::String&& value) { SetLogDestination(std::move(value)); return *this;}
@@ -596,14 +624,18 @@ namespace Model
      * <p>Specifies the destination to which the flow log data is to be published. Flow
      * log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket.
      * The value specified for this parameter depends on the value specified for
-     * <code>LogDestinationType</code>.</p> <p>If LogDestinationType is not specified
-     * or <code>cloud-watch-logs</code>, specify the Amazon Resource Name (ARN) of the
-     * CloudWatch Logs log group.</p> <p>If LogDestinationType is <code>s3</code>,
-     * specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the
-     * bucket. To specify a subfolder in the bucket, use the following ARN format:
-     * <code>bucket_ARN/subfolder_name/</code>. For example, to specify a subfolder
-     * named <code>my-logs</code> in a bucket named <code>my-bucket</code>, use the
-     * following ARN: <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
+     * <code>LogDestinationType</code>.</p> <p>If <code>LogDestinationType</code> is
+     * not specified or <code>cloud-watch-logs</code>, specify the Amazon Resource Name
+     * (ARN) of the CloudWatch Logs log group. For example, to publish to a log group
+     * called <code>my-logs</code>, specify
+     * <code>arn:aws:logs:us-east-1:123456789012:log-group:my-logs</code>.
+     * Alternatively, use <code>LogGroupName</code> instead.</p> <p>If
+     * LogDestinationType is <code>s3</code>, specify the ARN of the Amazon S3 bucket.
+     * You can also specify a subfolder in the bucket. To specify a subfolder in the
+     * bucket, use the following ARN format: <code>bucket_ARN/subfolder_name/</code>.
+     * For example, to specify a subfolder named <code>my-logs</code> in a bucket named
+     * <code>my-bucket</code>, use the following ARN:
+     * <code>arn:aws:s3:::my-bucket/my-logs/</code>. You cannot use
      * <code>AWSLogs</code> as a subfolder name. This is a reserved term.</p>
      */
     inline CreateFlowLogsRequest& WithLogDestination(const char* value) { SetLogDestination(value); return *this;}
@@ -713,6 +745,47 @@ namespace Model
      */
     inline CreateFlowLogsRequest& WithLogFormat(const char* value) { SetLogFormat(value); return *this;}
 
+
+    /**
+     * <p>The maximum interval of time during which a flow of packets is captured and
+     * aggregated into a flow log record. You can specify 60 seconds (1 minute) or 600
+     * seconds (10 minutes).</p> <p>For network interfaces attached to <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
+     * instances</a>, the aggregation interval is always 60 seconds, regardless of the
+     * value that you specify.</p> <p>Default: 600</p>
+     */
+    inline int GetMaxAggregationInterval() const{ return m_maxAggregationInterval; }
+
+    /**
+     * <p>The maximum interval of time during which a flow of packets is captured and
+     * aggregated into a flow log record. You can specify 60 seconds (1 minute) or 600
+     * seconds (10 minutes).</p> <p>For network interfaces attached to <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
+     * instances</a>, the aggregation interval is always 60 seconds, regardless of the
+     * value that you specify.</p> <p>Default: 600</p>
+     */
+    inline bool MaxAggregationIntervalHasBeenSet() const { return m_maxAggregationIntervalHasBeenSet; }
+
+    /**
+     * <p>The maximum interval of time during which a flow of packets is captured and
+     * aggregated into a flow log record. You can specify 60 seconds (1 minute) or 600
+     * seconds (10 minutes).</p> <p>For network interfaces attached to <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
+     * instances</a>, the aggregation interval is always 60 seconds, regardless of the
+     * value that you specify.</p> <p>Default: 600</p>
+     */
+    inline void SetMaxAggregationInterval(int value) { m_maxAggregationIntervalHasBeenSet = true; m_maxAggregationInterval = value; }
+
+    /**
+     * <p>The maximum interval of time during which a flow of packets is captured and
+     * aggregated into a flow log record. You can specify 60 seconds (1 minute) or 600
+     * seconds (10 minutes).</p> <p>For network interfaces attached to <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
+     * instances</a>, the aggregation interval is always 60 seconds, regardless of the
+     * value that you specify.</p> <p>Default: 600</p>
+     */
+    inline CreateFlowLogsRequest& WithMaxAggregationInterval(int value) { SetMaxAggregationInterval(value); return *this;}
+
   private:
 
     bool m_dryRun;
@@ -744,6 +817,9 @@ namespace Model
 
     Aws::String m_logFormat;
     bool m_logFormatHasBeenSet;
+
+    int m_maxAggregationInterval;
+    bool m_maxAggregationIntervalHasBeenSet;
   };
 
 } // namespace Model
