@@ -236,6 +236,35 @@ namespace Model
     inline ModifyClientVpnEndpointRequest& WithDnsServers(DnsServersOptionsModifyStructure&& value) { SetDnsServers(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The port number to assign to the Client VPN endpoint for TCP and UDP
+     * traffic.</p> <p>Valid Values: <code>443</code> | <code>1194</code> </p>
+     * <p>Default Value: <code>443</code> </p>
+     */
+    inline int GetVpnPort() const{ return m_vpnPort; }
+
+    /**
+     * <p>The port number to assign to the Client VPN endpoint for TCP and UDP
+     * traffic.</p> <p>Valid Values: <code>443</code> | <code>1194</code> </p>
+     * <p>Default Value: <code>443</code> </p>
+     */
+    inline bool VpnPortHasBeenSet() const { return m_vpnPortHasBeenSet; }
+
+    /**
+     * <p>The port number to assign to the Client VPN endpoint for TCP and UDP
+     * traffic.</p> <p>Valid Values: <code>443</code> | <code>1194</code> </p>
+     * <p>Default Value: <code>443</code> </p>
+     */
+    inline void SetVpnPort(int value) { m_vpnPortHasBeenSet = true; m_vpnPort = value; }
+
+    /**
+     * <p>The port number to assign to the Client VPN endpoint for TCP and UDP
+     * traffic.</p> <p>Valid Values: <code>443</code> | <code>1194</code> </p>
+     * <p>Default Value: <code>443</code> </p>
+     */
+    inline ModifyClientVpnEndpointRequest& WithVpnPort(int value) { SetVpnPort(value); return *this;}
+
+
     /**
      * <p>A brief description of the Client VPN endpoint.</p>
      */
@@ -360,6 +389,9 @@ namespace Model
     DnsServersOptionsModifyStructure m_dnsServers;
     bool m_dnsServersHasBeenSet;
 
+    int m_vpnPort;
+    bool m_vpnPortHasBeenSet;
+
     Aws::String m_description;
     bool m_descriptionHasBeenSet;
 
