@@ -24,6 +24,7 @@
 #include <aws/ecs/model/LoadBalancer.h>
 #include <aws/ecs/model/ServiceRegistry.h>
 #include <aws/ecs/model/CapacityProviderStrategyItem.h>
+#include <aws/ecs/model/Tag.h>
 #include <utility>
 
 namespace Aws
@@ -774,6 +775,175 @@ namespace Model
      */
     inline CreateTaskSetRequest& WithClientToken(const char* value) { SetClientToken(value); return *this;}
 
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline const Aws::Vector<Tag>& GetTags() const{ return m_tags; }
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline void SetTags(const Aws::Vector<Tag>& value) { m_tagsHasBeenSet = true; m_tags = value; }
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline void SetTags(Aws::Vector<Tag>&& value) { m_tagsHasBeenSet = true; m_tags = std::move(value); }
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline CreateTaskSetRequest& WithTags(const Aws::Vector<Tag>& value) { SetTags(value); return *this;}
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline CreateTaskSetRequest& WithTags(Aws::Vector<Tag>&& value) { SetTags(std::move(value)); return *this;}
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline CreateTaskSetRequest& AddTags(const Tag& value) { m_tagsHasBeenSet = true; m_tags.push_back(value); return *this; }
+
+    /**
+     * <p>The metadata that you apply to the task set to help you categorize and
+     * organize them. Each tag consists of a key and an optional value, both of which
+     * you define. When a service is deleted, the tags are deleted as well.</p> <p>The
+     * following basic restrictions apply to tags:</p> <ul> <li> <p>Maximum number of
+     * tags per resource - 50</p> </li> <li> <p>For each resource, each tag key must be
+     * unique, and each tag key can have only one value.</p> </li> <li> <p>Maximum key
+     * length - 128 Unicode characters in UTF-8</p> </li> <li> <p>Maximum value length
+     * - 256 Unicode characters in UTF-8</p> </li> <li> <p>If your tagging schema is
+     * used across multiple services and resources, remember that other services may
+     * have restrictions on allowed characters. Generally allowed characters are:
+     * letters, numbers, and spaces representable in UTF-8, and the following
+     * characters: + - = . _ : / @.</p> </li> <li> <p>Tag keys and values are
+     * case-sensitive.</p> </li> <li> <p>Do not use <code>aws:</code>,
+     * <code>AWS:</code>, or any upper or lowercase combination of such as a prefix for
+     * either keys or values as it is reserved for AWS use. You cannot edit or delete
+     * tag keys or values with this prefix. Tags with this prefix do not count against
+     * your tags per resource limit.</p> </li> </ul>
+     */
+    inline CreateTaskSetRequest& AddTags(Tag&& value) { m_tagsHasBeenSet = true; m_tags.push_back(std::move(value)); return *this; }
+
   private:
 
     Aws::String m_service;
@@ -811,6 +981,9 @@ namespace Model
 
     Aws::String m_clientToken;
     bool m_clientTokenHasBeenSet;
+
+    Aws::Vector<Tag> m_tags;
+    bool m_tagsHasBeenSet;
   };
 
 } // namespace Model
