@@ -133,50 +133,42 @@ namespace Model
 
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline const Aws::String& GetCharacterSetName() const{ return m_characterSetName; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline bool CharacterSetNameHasBeenSet() const { return m_characterSetNameHasBeenSet; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(const Aws::String& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = value; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(Aws::String&& value) { m_characterSetNameHasBeenSet = true; m_characterSetName = std::move(value); }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetCharacterSetName(const char* value) { m_characterSetNameHasBeenSet = true; m_characterSetName.assign(value); }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithCharacterSetName(const Aws::String& value) { SetCharacterSetName(value); return *this;}
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithCharacterSetName(Aws::String&& value) { SetCharacterSetName(std::move(value)); return *this;}
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified CharacterSet.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithCharacterSetName(const char* value) { SetCharacterSetName(value); return *this;}
 
@@ -529,50 +521,50 @@ namespace Model
 
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline const Aws::String& GetEngineVersion() const{ return m_engineVersion; }
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline bool EngineVersionHasBeenSet() const { return m_engineVersionHasBeenSet; }
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline void SetEngineVersion(const Aws::String& value) { m_engineVersionHasBeenSet = true; m_engineVersion = value; }
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline void SetEngineVersion(Aws::String&& value) { m_engineVersionHasBeenSet = true; m_engineVersion = std::move(value); }
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline void SetEngineVersion(const char* value) { m_engineVersionHasBeenSet = true; m_engineVersion.assign(value); }
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline CreateDBClusterRequest& WithEngineVersion(const Aws::String& value) { SetEngineVersion(value); return *this;}
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline CreateDBClusterRequest& WithEngineVersion(Aws::String&& value) { SetEngineVersion(std::move(value)); return *this;}
 
     /**
-     * <p>The version number of the database engine to use.</p> <p>Example:
-     * <code>1.0.1</code> </p>
+     * <p>The version number of the database engine to use. Currently, setting this
+     * parameter has no effect.</p> <p>Example: <code>1.0.1</code> </p>
      */
     inline CreateDBClusterRequest& WithEngineVersion(const char* value) { SetEngineVersion(value); return *this;}
 
@@ -725,66 +717,42 @@ namespace Model
 
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline const Aws::String& GetOptionGroupName() const{ return m_optionGroupName; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline bool OptionGroupNameHasBeenSet() const { return m_optionGroupNameHasBeenSet; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetOptionGroupName(const Aws::String& value) { m_optionGroupNameHasBeenSet = true; m_optionGroupName = value; }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetOptionGroupName(Aws::String&& value) { m_optionGroupNameHasBeenSet = true; m_optionGroupName = std::move(value); }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline void SetOptionGroupName(const char* value) { m_optionGroupNameHasBeenSet = true; m_optionGroupName.assign(value); }
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithOptionGroupName(const Aws::String& value) { SetOptionGroupName(value); return *this;}
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithOptionGroupName(Aws::String&& value) { SetOptionGroupName(std::move(value)); return *this;}
 
     /**
-     * <p>A value that indicates that the DB cluster should be associated with the
-     * specified option group.</p> <p>Permanent options can't be removed from an option
-     * group. The option group can't be removed from a DB cluster once it is associated
-     * with a DB cluster.</p>
+     * <p> <i>(Not supported by Neptune)</i> </p>
      */
     inline CreateDBClusterRequest& WithOptionGroupName(const char* value) { SetOptionGroupName(value); return *this;}
 
@@ -1411,6 +1379,35 @@ namespace Model
      */
     inline CreateDBClusterRequest& AddEnableCloudwatchLogsExports(const char* value) { m_enableCloudwatchLogsExportsHasBeenSet = true; m_enableCloudwatchLogsExports.push_back(value); return *this; }
 
+
+    /**
+     * <p>A value that indicates whether the DB cluster has deletion protection
+     * enabled. The database can't be deleted when deletion protection is enabled. By
+     * default, deletion protection is disabled. </p>
+     */
+    inline bool GetDeletionProtection() const{ return m_deletionProtection; }
+
+    /**
+     * <p>A value that indicates whether the DB cluster has deletion protection
+     * enabled. The database can't be deleted when deletion protection is enabled. By
+     * default, deletion protection is disabled. </p>
+     */
+    inline bool DeletionProtectionHasBeenSet() const { return m_deletionProtectionHasBeenSet; }
+
+    /**
+     * <p>A value that indicates whether the DB cluster has deletion protection
+     * enabled. The database can't be deleted when deletion protection is enabled. By
+     * default, deletion protection is disabled. </p>
+     */
+    inline void SetDeletionProtection(bool value) { m_deletionProtectionHasBeenSet = true; m_deletionProtection = value; }
+
+    /**
+     * <p>A value that indicates whether the DB cluster has deletion protection
+     * enabled. The database can't be deleted when deletion protection is enabled. By
+     * default, deletion protection is disabled. </p>
+     */
+    inline CreateDBClusterRequest& WithDeletionProtection(bool value) { SetDeletionProtection(value); return *this;}
+
   private:
 
     Aws::Vector<Aws::String> m_availabilityZones;
@@ -1481,6 +1478,9 @@ namespace Model
 
     Aws::Vector<Aws::String> m_enableCloudwatchLogsExports;
     bool m_enableCloudwatchLogsExportsHasBeenSet;
+
+    bool m_deletionProtection;
+    bool m_deletionProtectionHasBeenSet;
   };
 
 } // namespace Model
